# Part of Odoo. See LICENSE file for full copyright and licensing details.
from . import template_in
from . import account_invoice
from . import account_move_line
from . import account_tax
from . import company
from . import iap_account
from . import product_template
from . import port_code
from . import res_config_settings
from . import res_country_state
from . import res_partner
from . import uom_uom
